==> source-highlight-qt_0.1.orig.tar.gz: source-highlight-qt-0.1/lib/srchiliteqt/Qt4TextFormatterFactory.cpp <==
/*
 * Qt4TextFormatterFactory.cpp
 *
 *  Created on: Dec 7, 2008
 *      Author: Lorenzo Bettini <http://www.lorenzobettini.it>, (C) 2008
 *  Copyright: See COPYING file that comes with this distribution
 */

#include "Qt4TextFormatterFactory.h"
#include "Qt4TextFormatter.h"

#include <QColor>
#include <QBrush>

using namespace srchilite;

namespace srchiliteqt {

Qt4TextFormatterFactory::Qt4TextFormatterFactory() {
}

Qt4TextFormatterFactory::~Qt4TextFormatterFactory() {
}

bool Qt4TextFormatterFactory::createFormatter(const string &key,
        const string &color, const string &bgcolor,
        srchilite::StyleConstantsPtr styleconstants) {

    if (hasFormatter(key))
        return false;

    Qt4TextFormatter *formatter = new Qt4TextFormatter(key);
    addFormatter(key, TextFormatterPtr(formatter));

    // check whether we should default to monospace
    if (isDefaultToMonosapce())
        formatter->getQTextCharFormat().setFontFamily("Monospace");

    if (styleconstants.get()) {
        for (StyleConstantsIterator it = styleconstants->begin(); it
                != styleconstants->end(); ++it) {
            switch (*it) {
            case ISBOLD:
                formatter->getQTextCharFormat().setFontWeight(QFont::Bold);
                break;
            case ISITALIC:
                formatter->getQTextCharFormat().setFontItalic(true);
                break;
            case ISUNDERLINE:
                formatter->getQTextCharFormat().setFontUnderline(true);
                break;
            case ISFIXED:
                formatter->getQTextCharFormat().setFontFamily("Monospace");
                formatter->getQTextCharFormat().setFontFixedPitch(true);
                break;
            case ISNOTFIXED:
                formatter->getQTextCharFormat().setFontFixedPitch(false);
                break;
            case ISNOREF:
                break;
            }
        }
    }

    if (color.size()) {
        formatter->setForegroundColor(colorMap.getColor(color).c_str());
    }

    if (bgcolor.size()) {
        formatter->setBackgroundColor(colorMap.getColor(bgcolor).c_str());
    }

    return true;
}

}

==> source-highlight-qt_0.2.orig.tar.gz: source-highlight-qt-0.2/lib/srchiliteqt/Qt4TextFormatterFactory.cpp <==
/*
 * Qt4TextFormatterFactory.cpp
 *
 *  Created on: Dec 7, 2008
 *      Author: Lorenzo Bettini <http://www.lorenzobettini.it>, (C) 2008
 *  Copyright: See COPYING file that comes with this distribution
 */

#include "Qt4TextFormatterFactory.h"
#include "Qt4TextFormatter.h"

#include <QColor>
#include <QBrush>

using namespace srchilite;

namespace srchiliteqt {

Qt4TextFormatterFactory::Qt4TextFormatterFactory() {
}

Qt4TextFormatterFactory::~Qt4TextFormatterFactory() {
}

bool Qt4TextFormatterFactory::createFormatter(const string &key,
        const string &color, const string &bgcolor,
        srchilite::StyleConstantsPtr styleconstants) {

    if (hasFormatter(key))
        return false;

    Qt4TextFormatter *formatter = new Qt4TextFormatter(key);
    addFormatter(key, TextFormatterPtr(formatter));

    // check whether we should default to monospace
    if (isDefaultToMonosapce())
        formatter->setMonospace(true);

    if (styleconstants.get()) {
        for (StyleConstantsIterator it = styleconstants->begin(); it
                != styleconstants->end(); ++it) {
            switch (*it) {
            case ISBOLD:
                formatter->setBold(true);
                break;
            case ISITALIC:
                formatter->setItalic(true);
                break;
            case ISUNDERLINE:
                formatter->setUnderline(true);
                break;
            case ISFIXED:
                formatter->setMonospace(true);
                //formatter->getQTextCharFormat().setFontFixedPitch(true);
                break;
            case ISNOTFIXED:
                formatter->setMonospace(false);
                break;
            case ISNOREF:
                break;
            }
        }
    }

    if (color.size()) {
        formatter->setForegroundColor(colorMap.getColor(color).c_str());
    }

    if (bgcolor.size()) {
        formatter->setBackgroundColor(colorMap.getColor(bgcolor).c_str());
    }

    return true;
}

}
